You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@hawq.apache.org by hu...@apache.org on 2015/10/29 12:45:30 UTC

incubator-hawq git commit: HAWQ-110. Re-phrase error message for gpcheckhdfs to make it consistent with hawq management utilities

Repository: incubator-hawq
Updated Branches:
  refs/heads/master 3dc0d7bda -> d0dfbb16d


HAWQ-110. Re-phrase error message for gpcheckhdfs to make it consistent with hawq management utilities


Project: http://git-wip-us.apache.org/repos/asf/incubator-hawq/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-hawq/commit/d0dfbb16
Tree: http://git-wip-us.apache.org/repos/asf/incubator-hawq/tree/d0dfbb16
Diff: http://git-wip-us.apache.org/repos/asf/incubator-hawq/diff/d0dfbb16

Branch: refs/heads/master
Commit: d0dfbb16d5bfbe145ede934064d2b14348b7a316
Parents: 3dc0d7b
Author: Ruilong Huo <rh...@pivotal.io>
Authored: Thu Oct 29 19:36:49 2015 +0800
Committer: Ruilong Huo <rh...@pivotal.io>
Committed: Thu Oct 29 19:36:49 2015 +0800

----------------------------------------------------------------------
 src/bin/gpcheckhdfs/gpcheckhdfs.c | 10 +++++++---
 1 file changed, 7 insertions(+), 3 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-hawq/blob/d0dfbb16/src/bin/gpcheckhdfs/gpcheckhdfs.c
----------------------------------------------------------------------
diff --git a/src/bin/gpcheckhdfs/gpcheckhdfs.c b/src/bin/gpcheckhdfs/gpcheckhdfs.c
index abafe2a..38eaf34 100644
--- a/src/bin/gpcheckhdfs/gpcheckhdfs.c
+++ b/src/bin/gpcheckhdfs/gpcheckhdfs.c
@@ -2,8 +2,12 @@
  *
  * gpcheckhdfs.c
  *
  * This file mainly provide checking Hdfs when run gpinitsystem.It uses libhdfs
  * to communicate with HDFS.
  *
  * Copyright (c) 2014, Greenplum inc
  *
@@ -246,7 +250,7 @@ int testHdfsExisted(hdfsFS fs, const char * filepath, const char * dfscompleteur
 
         if (NULL == fi || num != 0) {
             fprintf(stderr, "ERROR: failed to list directory %s or it is not empty\n"
-                    "Please Check your filepath before run gpinitsystem\n", dfscompleteurl);
+                    "Please Check your filepath before doing HAWQ cluster initialization.\n", dfscompleteurl);
             return DFSDIR_ERR;
         }
     }
@@ -2,8 +2,12 @@
  * gpcheckhdfs.c
  *
- * This file mainly provide checking Hdfs when run gpinitsystem.It uses libhdfs
- * to communicate with HDFS.
+ * This file mainly provide functionalities to check status of
+ * HDFS cluster when:
+ *     1. doing HAWQ cluster initialization;
+ *     2. monitoring HDFS cluster health manually.
+ *
+ * It uses libhdfs to communicate with HDFS.
  *
  * Copyright (c) 2014, Greenplum inc